@@ -7,7 +7,6 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 from time import time
-from sklearn.metrics import mean_squared_error, roc_auc_score, average_precision_score, f1_score, log_loss
 import pickle 
 torch.manual_seed(2)
 np.random.seed(3)
@@ -17,7 +16,6 @@ import os
 from datetime import datetime
 import json
 import wandb
-from tqdm import tqdm
 
 from DeepMTP.utils.data_utils import *
 from DeepMTP.branch_models import *
@@ -58,8 +56,6 @@ class DeepMTP:
 
 	def __init__(self, config, checkpoint_dir=None):
 
-		print('CURRENT DIR: '+str(os.getcwd()))
-
 		self.checkpoint_dict = None
 		self.wandb_run = None
 		self.tensorboard_logger = None
@@ -163,7 +159,7 @@ class DeepMTP:
 			metric_to_track=self.config['metric_to_optimize_early_stopping'] if self.config['use_early_stopping'] else self.config['metric_to_optimize_best_epoch_selection']
 		)
 
-	def inference(self, model, dataloader, mode, epoch, return_predictions=False, verbose=False):
+	def inference(self, model, dataloader, mode, epoch=0, return_predictions=False, verbose=False):
 		model.eval()
 		with torch.no_grad():
 			loss_arr = []
